@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Common;
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use base 'Exporter';
 
@@ -20,13 +20,13 @@ our @EXPORT_OK = qw/
 /;
 
 use constant {
-    YAML_ANY_SCALAR_STYLE           => 'A',
-    YAML_PLAIN_SCALAR_STYLE         => ':',
-    YAML_SINGLE_QUOTED_SCALAR_STYLE => "'",
-    YAML_DOUBLE_QUOTED_SCALAR_STYLE => '"',
-    YAML_LITERAL_SCALAR_STYLE       => '|',
-    YAML_FOLDED_SCALAR_STYLE        => '>',
-    YAML_QUOTED_SCALAR_STYLE        => 'Q',
+    YAML_ANY_SCALAR_STYLE           => 0,
+    YAML_PLAIN_SCALAR_STYLE         => 1,
+    YAML_SINGLE_QUOTED_SCALAR_STYLE => 2,
+    YAML_DOUBLE_QUOTED_SCALAR_STYLE => 3,
+    YAML_LITERAL_SCALAR_STYLE       => 4,
+    YAML_FOLDED_SCALAR_STYLE        => 5,
+    YAML_QUOTED_SCALAR_STYLE        => 'Q', # deprecated
 
     YAML_ANY_SEQUENCE_STYLE   => 'any',
     YAML_BLOCK_SEQUENCE_STYLE => 'block',
@@ -210,7 +210,6 @@ YAML::PP::Common - Constants and common functions
         YAML_ANY_SCALAR_STYLE YAML_PLAIN_SCALAR_STYLE
         YAML_SINGLE_QUOTED_SCALAR_STYLE YAML_DOUBLE_QUOTED_SCALAR_STYLE
         YAML_LITERAL_SCALAR_STYLE YAML_FOLDED_SCALAR_STYLE
-        YAML_QUOTED_SCALAR_STYLE
     /;
 
 =head1 DESCRIPTION
